Rates — SoL 3 developers documentation

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »

# Rates

class `sol.models.rate.` `Rate`(**kwargs)

  The Glicko rating of a player.

  `caption`(html=None, localized=True)

    A description of the rate.

  `date`

    Rating date.

  `deviation`

    The value of Glicko deviation.

  `idplayer`

    Related player’s ID.

  `idrate`

    Primary key.

  `idrating`

    Related rating’s ID.

  `player`

    The related player.

  `rate`

    The value of Glicko rating.

  `serialize`(serializer)

    Reduce a single rate to a simple dictionary

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »